@@ -4,9 +4,7 @@
  * GChemPaint library
  * about.cc 
  *
- * Copyright (C) 2004-2005
- *
- * Developed by Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2004-2005 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -34,7 +32,6 @@ void on_about (GtkWidget* widget, void* data)
 {
 	char * authors[] = {"Jean Bréfort", NULL};
 	char * artists[] = {"Nestor Diaz", NULL};
-	char * documentors[] = {NULL};
 	char license[] = "This program is free software; you can redistribute it and/or\n" 
 		"modify it under the terms of the GNU General Public License as\n"
  		"published by the Free Software Foundation; either version 2 of the\n"
@@ -49,7 +46,7 @@ void on_about (GtkWidget* widget, void* data)
 		"USA";
 /* Note to translators: replace the following string with the appropriate credits for you lang */
 	char *translator_credits = _("translator_credits");
-	GdkPixbuf* pixbuf = gdk_pixbuf_new_from_file ( DATADIR"/"PACKAGE"/pixmaps/gchempaint_logo.png", NULL);
+	GdkPixbuf* pixbuf = gdk_pixbuf_new_from_file ( PKGDATADIR"/pixmaps/gchempaint_logo.png", NULL);
 	gtk_show_about_dialog (NULL,
 					"name", "GChemPaint",
 					"authors", authors,
