@@ -4,9 +4,7 @@
  * GChemPaint library
  * reactant.cc 
  *
- * Copyright (C) 2002-2005
- *
- * Developed by Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2002-2005 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -20,7 +18,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
  * USA
  */
 
@@ -218,7 +216,6 @@ bool gcpReactant::OnSignal (SignalId Signal, Object *Obj)
 			xmlNodePtr node = NULL;
 			bool ChildFound = false;
 			gcpReactionStep *step = reinterpret_cast<gcpReactionStep*> (GetParent ());
-			int new_objs = (Stoichiometry)? n - 2: n - 1;
 			if (Stoichiometry)
 				node = Stoichiometry->Save (pXmlDoc);
 			pObj = GetFirstChild (i);
