@@ -4,9 +4,7 @@
  * GChemPaint arrows plugin
  * plugin.cc 
  *
- * Copyright (C) 2004
- *
- * Developed by Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2004 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -76,7 +74,7 @@ void gcpArrowsPlugin::Populate (gcpApplication* App)
 	}
 	gconf_client_remove_dir (conf_client, "/apps/gchempaint/plugins/arrows", NULL);
 	g_object_unref (conf_client);
-	App->AddUI (DATADIR"/gchempaint/ui/arrows.xml");
+	App->AddUI (PKGDATADIR"/ui/arrows.xml");
 	new gcpArrowTool (App);
 	new gcpArrowTool (App, FullHeads? gcpFullReversibleArrow: gcpReversibleArrow);
 	new gcpArrowTool (App, gcpDoubleHeadedArrow);
