@@ -4,9 +4,7 @@
  * GChemPaint bonds plugin
  * plugin.cc 
  *
- * Copyright (C) 2004
- *
- * Developed by Jean Bréfort <jean.brefort@ac-dijon.fr>
+ * Copyright (C) 2004 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -20,7 +18,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
  * USA
  */
 
@@ -28,7 +26,6 @@
 #include "plugin.h"
 #include "lib/application.h"
 #include "bondtool.h"
-#include "delocalizedtool.h"
 
 gcpBondsPlugin plugin;
 
@@ -42,10 +39,9 @@ gcpBondsPlugin::~gcpBondsPlugin()
 
 void gcpBondsPlugin::Populate (gcpApplication* App)
 {
-	App->AddUI (DATADIR"/gchempaint/ui/bonds.xml");
+	App->AddUI (PKGDATADIR"/ui/bonds.xml");
 	new gcpBondTool(App);
 	new gcpUpBondTool (App);
 	new gcpDownBondTool (App);
 	new gcpSquiggleBondTool (App);
-	new gcpDelocalizedTool (App);
 }
