@@ -4,9 +4,7 @@
  * GChemPaint cycles plugin
  * cycletool.cc 
  *
- * Copyright (C) 2001-2005
- *
- * Developed by Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2001-2005 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -781,7 +779,7 @@ void gcpNCycleTool::SetOptions()
 	else gdk_window_raise (GTK_WIDGET(dlg->GetWindow())->window); 
 }
 
-gcpCNToolDlg::gcpCNToolDlg(gcpApplication* App, unsigned char size): gcpDialog(App, DATADIR"/gchempaint/ui/cyclentool.glade", "cyclentool")
+gcpCNToolDlg::gcpCNToolDlg(gcpApplication* App, unsigned char size): gcpDialog(App, PKGDATADIR"/ui/cyclentool.glade", "cyclentool")
 {
 	m_button = GTK_SPIN_BUTTON(glade_xml_get_widget(xml, "sizebtn"));
 	gtk_spin_button_set_value(m_button, size);
