@@ -4,9 +4,7 @@
  * GChemPaint selection plugin
  * plugin.cc 
  *
- * Copyright (C) 2004
- *
- * Developed by Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2004 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -50,7 +48,7 @@ gcpSelectionPlugin::~gcpSelectionPlugin()
 
 void gcpSelectionPlugin::Populate (gcpApplication* App)
 {
-	App->AddUI (DATADIR"/gchempaint/ui/selection.xml");
+	App->AddUI (PKGDATADIR"/ui/selection.xml");
 	new gcpSelectionTool (App);
 	new gcpEraserTool (App);
 	App->ActivateTool ("Select", true);
