@@ -4,9 +4,7 @@
  * GChemPaint
  * standaloneapp.cc
  *
- * Copyright (C) 2004-2005
- *
- * Developed by Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2004-2005 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -146,13 +144,6 @@ static bool on_key_press(GtkWidget* widget, GdkEventKey* ev, gcpStandaloneApp* A
 	return App->OnKeyPressed(widget, ev);
 }
 
-static void on_prefs(GtkWidget* widget, gcpStandaloneApp* App)
-{
-/*	GtkFontSelectionDialog* dlg = (GtkFontSelectionDialog*)gtk_font_selection_dialog_new("");
-	gtk_dialog_run(GTK_DIALOG(dlg));
-	gtk_widget_destroy(GTK_WIDGET(dlg));*/
-}
-
 static void on_close_all(GtkWidget* widget, gcpStandaloneApp* App)
 {
 	App->OnCloseAll ();
@@ -381,10 +372,6 @@ static const char *ui_web_description =
 "  </menubar>"
 "</ui>";
 
-#warning "the following lines should be removed for stable releases"
-#undef PACKAGE
-#define PACKAGE "gchempaint-unstable" 
-
 gcpStandaloneApp::gcpStandaloneApp(): gcpApplication()
 {
 	GtkWidget *vbox;
@@ -563,7 +550,7 @@ void gcpStandaloneApp::OnFileNew()
 
 void gcpStandaloneApp::OnFileOpen()
 {
-	gcpFileChooser* fc = new gcpFileChooser (this, false);
+	new gcpFileChooser (this, false);
 }
 
 void  gcpStandaloneApp::AddDocument(gcpDocument* pDoc)
@@ -768,14 +755,13 @@ void gcpStandaloneApp::AddToolbar (BonoboUINode* Node, map<unsigned, GtkWidget*>
 			else button = gtk_tool_button_new (NULL, NULL);
 			if (GTK_IS_TOOL_BUTTON (button)) {
 				if (bonobo_ui_node_has_attr (Child, "pixtype")) {
-					const char* filename = NULL;
 					name = bonobo_ui_node_get_attr (Child, "pixtype");
 					if (!strcmp (name, "filename")) {
 						bonobo_ui_node_free_string (name);
 						char* filename = NULL;
 						if (bonobo_ui_node_has_attr (Child, "pixname")) {
 							name = bonobo_ui_node_get_attr (Child, "pixname");
-							filename = g_strconcat (DATADIR"/gchempaint/ui/", name, NULL);
+							filename = g_strconcat (PKGDATADIR"/ui/", name, NULL);
 							bonobo_ui_node_free_string (name);
 						}
 						if (filename) {
@@ -845,7 +831,7 @@ void gcpStandaloneApp::OnPrint()
 	GnomePrintConfig* config = gnome_print_config_default();
 	GnomePrintContext *pc;// = gnome_print_context_new(config);
 	GnomePrintJob *gpj = gnome_print_job_new(config);
-	int do_preview, copies = 1, collate = 0;
+	int do_preview = 0, copies = 1, collate = 0;
 	GnomePrintDialog *gpd;
 	gpd = GNOME_PRINT_DIALOG (gnome_print_dialog_new(gpj, (const guchar*)_("Print"), GNOME_PRINT_DIALOG_COPIES));
 	gtk_window_set_icon_name (GTK_WINDOW (gpd), "gchempaint");
