@@ -8,7 +8,7 @@ CORBA_Environment	 ev;
 static guint
 create_app (void)
 {
-	GtkWidget *box, *control, *label, *button;
+	GtkWidget *control;
 	BonoboWindow *bonobo_win;
 
 	BonoboUIContainer *uic;
@@ -35,7 +35,7 @@ create_app (void)
 					"a container for GChemPaint BonoboControl test");
 
 	/* get a widget, containing the control */
-	control = bonobo_widget_new_control ("OAFIID:gchempaint_unstable_control", BONOBO_OBJREF (uic));
+	control = bonobo_widget_new_control ("OAFIID:gchempaint_control", BONOBO_OBJREF (uic));
 	if (!control) 
 		g_error ("Can't create control\n");
 	bonobo_window_set_contents(bonobo_win,control);
@@ -57,10 +57,6 @@ create_app (void)
 	  int 
 main (int argc, char** argv)
 {
-	CORBA_ORB orb;
-
-	GnomeProgram* prog;
-	
 	CORBA_exception_init (&ev);
 	gtk_init (&argc, &argv);
 
